import java.awt.image.BufferedImage;

public class PixelBufferFilterAsBufferedImageFilter implements BufferedImageFilter {
	private PixelBufferFilter rgbPixelBufferFilter;
	private int[] rgbArray;
	
	public PixelBufferFilterAsBufferedImageFilter(PixelBufferFilter rgbPixelBufferFilter) {
		this.rgbPixelBufferFilter = rgbPixelBufferFilter;
		this.rgbArray = null;
	}
	
	public void filter(BufferedImage img) {
		int width = img.getWidth();
		int height = img.getHeight();
		int numPixels = width*height;
		
		// Ensure the size of the pixel buffer matches the number of pixels in the image
		if ((rgbArray == null) || (rgbArray.length != (width*height))) {
			rgbArray = null;
		}
		
		// Read the image's pixels into the pixel buffer
		rgbArray = img.getRGB(0, 0, width, height, rgbArray, 0, width);
		
		// Filter the contents of the pixel buffer
		rgbPixelBufferFilter.filter(width, height, rgbArray);
		
		// Store the pixel buffer back into the original image
		img.setRGB(0, 0, width, height, rgbArray, 0, width);
	}
	
	public String toString() {
		return rgbPixelBufferFilter.toString();
	}
}